"""Sub settings.

.. autoclass:: CreationSettings
.. autoclass:: AnnotationSettings

"""

from ._annotation_settings import AnnotationSettings
from ._creation_settings import CreationSettings
